@@ -11,12 +11,12 @@ module Network.Wai.Handler.Warp.HTTP2.HPACK (
   ) where
 
 import qualified Control.Exception as E
-import Control.Monad (unless)
-import Data.ByteString (ByteString)
 import Network.HPACK hiding (Buffer)
 import Network.HPACK.Token
 import Network.HTTP2
+
 import Network.Wai.Handler.Warp.HTTP2.Types
+import Network.Wai.Handler.Warp.Imports
 import Network.Wai.Handler.Warp.PackInt
 import qualified Network.Wai.Handler.Warp.Settings as S
 import Network.Wai.Handler.Warp.Types
@@ -87,13 +87,13 @@ hpackDecodeHeader hdrblk Context{..} = do
 {-# INLINE checkRequestHeader #-}
 checkRequestHeader :: ValueTable -> Bool
 checkRequestHeader reqvt
-  | just mMethod (== "CONNECT") = mPath == Nothing && mScheme == Nothing
-  | mStatus     /= Nothing      = False
-  | mMethod     == Nothing      = False
-  | mScheme     == Nothing      = False
-  | mPath       == Nothing      = False
+  | just mMethod (== "CONNECT") = isNothing mPath && isNothing mScheme
+  | isJust mStatus              = False
+  | isNothing mMethod           = False
+  | isNothing mScheme           = False
+  | isNothing mPath             = False
   | mPath       == Just ""      = False
-  | mConnection /= Nothing      = False
+  | isJust mConnection          = False
   | just mTE (/= "trailers")    = False
   | otherwise                   = True
   where
