@@ -4,32 +4,18 @@
 
 module Network.Wai.Handler.Warp.HTTP2.Sender (frameSender) where
 
-#if __GLASGOW_HASKELL__ < 709
-import Control.Applicative
-#endif
 import Control.Concurrent.STM
 import qualified Control.Exception as E
-import Control.Monad (void, when)
-import Data.Bits
 import qualified Data.ByteString as BS
 import Data.ByteString.Builder (Builder)
 import qualified Data.ByteString.Builder.Extra as B
-import Data.Maybe (isNothing)
-import Data.Word (Word8, Word32)
+import Data.IORef
 import Foreign.Ptr (Ptr, plusPtr)
 import Foreign.Storable (poke)
 import Network.HPACK (setLimitForEncoding, toHeaderTable)
 import Network.HTTP2
 import Network.HTTP2.Priority (isEmptySTM, dequeueSTM, Precedence)
 import Network.Wai
-import Network.Wai.Handler.Warp.Buffer
-import Network.Wai.Handler.Warp.HTTP2.EncodeFrame
-import Network.Wai.Handler.Warp.HTTP2.HPACK
-import Network.Wai.Handler.Warp.HTTP2.Manager (Manager)
-import Network.Wai.Handler.Warp.HTTP2.Types
-import Network.Wai.Handler.Warp.IORef
-import qualified Network.Wai.Handler.Warp.Settings as S
-import Network.Wai.Handler.Warp.Types
 
 #ifdef WINDOWS
 import qualified System.IO as IO
@@ -39,11 +25,20 @@ import Network.Wai.Handler.Warp.SendFile (positionRead)
 import qualified Network.Wai.Handler.Warp.Timeout as T
 #endif
 
+import Network.Wai.Handler.Warp.Buffer
+import Network.Wai.Handler.Warp.HTTP2.EncodeFrame
+import Network.Wai.Handler.Warp.HTTP2.HPACK
+import Network.Wai.Handler.Warp.HTTP2.Manager (Manager)
+import Network.Wai.Handler.Warp.HTTP2.Types
+import Network.Wai.Handler.Warp.Imports hiding (readInt)
+import qualified Network.Wai.Handler.Warp.Settings as S
+import Network.Wai.Handler.Warp.Types
+
 ----------------------------------------------------------------
 
 data Leftover = LZero
               | LOne B.BufferWriter
-              | LTwo BS.ByteString B.BufferWriter
+              | LTwo ByteString B.BufferWriter
 
 ----------------------------------------------------------------
 
@@ -61,7 +56,7 @@ waitStreamWindowSize Stream{streamWindow} = atomically $ do
 waitStreaming :: TBQueue a -> IO ()
 waitStreaming tbq = atomically $ do
     isEmpty <- isEmptyTBQueue tbq
-    check (isEmpty == False)
+    check (not isEmpty)
 
 data Switch = C Control
             | O (StreamId,Precedence,Output)
@@ -296,7 +291,7 @@ frameSender ctx@Context{outputQ,controlQ,connectionWindow,encodeDynamicTable}
             sendHeadersIfNecessary $ off0 + frameHeaderLength + kvlen
         handleEndOfBody True off0 noTrailers trailers = do
             off1 <- handleTrailers noTrailers off0 trailers
-            void $ tell
+            void tell
             closed ctx strm Finished
             return off1
         handleEndOfBody False off0 _ _ = return off0
