@@ -1,6 +1,5 @@
 module Network.Wai.Handler.Warp.HashMap where
 
-import Data.ByteString (ByteString)
 import Data.Hashable (hash)
 import Data.IntMap.Strict (IntMap)
 import qualified Data.IntMap.Strict as I
@@ -8,6 +7,8 @@ import Data.Map.Strict (Map)
 import qualified Data.Map.Strict as M
 import Prelude hiding (lookup)
 
+import Network.Wai.Handler.Warp.Imports hiding (insert, lookup)
+
 type Hash = Int
 newtype HashMap k v = HashMap (IntMap (Map k v))
 
@@ -15,7 +16,7 @@ hashByteString :: ByteString -> Hash
 hashByteString = hash
 
 empty :: HashMap k v
-empty = HashMap $ I.empty
+empty = HashMap I.empty
 
 null :: HashMap k v -> Bool
 null (HashMap hm) = I.null hm
