@@ -7,6 +7,7 @@ import           Control.Exception
 import           Network.HTTP.Types
 import           Network.Socket
 import           Network.Wai
+import           System.Environment
 import           System.IO
 import           System.IO.Silently
 import           System.Process
@@ -16,6 +17,9 @@ import           Network.Wai.Handler.Warp.WithApplication
 
 spec :: Spec
 spec = do
+  runIO $ do
+      unsetEnv "http_proxy"
+      unsetEnv "https_proxy"
   describe "withApplication" $ do
     it "runs a wai Application while executing the given action" $ do
       let mkApp = return $ \ _request respond -> respond $ responseLBS ok200 [] "foo"
@@ -38,8 +42,10 @@ spec = do
             readProcess "curl" ["-s", "localhost:" ++ show port] "")
           `shouldThrow` (errorCall "foo")
 
+{- The future netwrok library will not export MkSocket.
   describe "withFreePort" $ do
     it "closes the socket before exiting" $ do
       MkSocket _ _ _ _ statusMVar <- withFreePort $ \ (_, sock) -> do
         return sock
       readMVar statusMVar `shouldReturn` Closed
+-}
